@@ -85,4 +85,24 @@ def test_less():
 
 def test_less_equal():
     check.less_equal(1, 2)
-    check.less_equal(1, 1)
\ No newline at end of file
+    check.less_equal(1, 1)
+
+
+def test_between():
+    check.between(10, 0, 20)
+
+
+def test_between_ge():
+    check.between(10, 0, 20, ge=True)
+    check.between(0, 0, 20, ge=True)
+
+
+def test_between_le():
+    check.between(10, 0, 20, le=True)
+    check.between(20, 0, 20, le=True)
+
+
+def test_between_ge_le():
+    check.between(0, 0, 20, ge=True, le=True)
+    check.between(10, 0, 20, ge=True, le=True)
+    check.between(20, 0, 20, ge=True, le=True)
